@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::RJBS 5.016;
+package Dist::Zilla::PluginBundle::RJBS 5.017;
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -9,6 +9,7 @@ with
     'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
 use v5.20.0;
+use experimental 'postderef'; # Not really an experiment anymore.
 
 #pod =head1 DESCRIPTION
 #pod
@@ -63,6 +64,30 @@ use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Git;
 
+package Dist::Zilla::Plugin::RJBSMisc 5.017 {
+  use Moose;
+  with 'Dist::Zilla::Role::BeforeBuild',
+       'Dist::Zilla::Role::AfterBuild';
+
+  has perl_support => (is => 'ro');
+
+  sub before_build {
+    my ($self) = @_;
+
+    if (($self->perl_support // '') eq 'toolchain' && $self->package_name_version) {
+      $self->log_fatal('This dist claims to be toolchain but uses "package NAME VERSION"');
+    }
+  }
+
+  sub after_build {
+    my ($self) = @_;
+
+    if (grep {; /rjbs\@cpan\.org/ } $self->zilla->authors->@*) {
+      $self->log('Authors still contain rjbs@cpan.org!  Needs an update.');
+    }
+  }
+}
+
 has manual_version => (
   is      => 'ro',
   isa     => 'Bool',
@@ -233,6 +258,12 @@ sub configure {
     ]);
   }
 
+  $self->add_plugins(
+    [ RJBSMisc => {
+        perl_support => $self->perl_support,
+    } ],
+  );
+
   $self->add_plugins(
     [ GithubMeta => {
       remote => [ qw(github) ],
@@ -268,7 +299,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.016
+version 5.017
 
 =head1 DESCRIPTION
 
